<template>
<div class="devOnlineLineContainer">
  <echarts chart-id="devOnlineLine" :chart-option="options"></echarts>
</div>
</template>

<script>
import * as echarts from 'echarts'
export default {
  name: 'devOnlineLine',
  components: {},
  props: {
    selected: {
      type: String,
      default: ''
    }
  },
  data() {
    return {
      options: {
        grid: {
          top: "10%",
          left: '10%',
          right: '0',
          bottom: "20%"
        },
        tooltip: {
          trigger: "axis",
          axisPointer: {
            type: "shadow",
            label: {
              show: true
            }
          }
        },
        xAxis: {
          boundaryGap: false,
          data: [
            "00:00",
            "02:00",
            "04:00",
            "06:00",
            "08:00",
            "10:00",
            "12:00",
            "14:00",
          ],
          splitLine: {
            show: true,
            interval: 0,
            lineStyle: {
              color: 'rgba(250,250,250,0.2)',
              type: 'dashed'
            }
          },
          axisLine: {
            show: true, //隐藏X轴轴线
            lineStyle: {
              color: 'rgba(250,250,250,0.4)',
              width: 1
            }
          },
          axisTick: {
            show: false //隐藏X轴刻度
          },
          axisLabel: {
            show: true,
            interval: 1,
            textStyle: {
              color: "rgba(126,206,244,0.6)", //X轴文字颜色
              fontSize: 12
            }
          },
          splitArea: {
            show: false,
            interval: 0,
            areaStyle: {
              color: ["rgba(30, 47, 66, 0.35)", "rgba(250,250,250,0)"]
            }
          }
        },
        yAxis: {
          type: "value",
          splitLine: {
            show: true,
            lineStyle: {
              color: 'rgba(250,250,250,0.2)',
              type: 'dashed'
            }
          },
          splitNumber: 3,
          axisTick: {
            show: false
          },
          axisLine: {
            show: false
          },
          axisLabel: {
            show: true,
            textStyle: {
              color: "rgba(126,206,244,0.6)",
              fontSize: 12
            }
          },
        },
        series: [{
          name: "",
          type: "line",
          smooth: true, //平滑曲线显示
          showAllSymbol: true, //显示所有图形。
          symbol: "none", //标记的图形为实心圆
          lineStyle: {
            color: "#00C6FF",
            width: 2
          },
          areaStyle: {
            color: new echarts.graphic.LinearGradient(0, 0, 0, 1, [{
                offset: 0,
                color: "rgba(0, 198, 255, .8)"
              },
              {
                offset: 1,
                color: "rgba(0, 198, 255, 0)"
              }
            ])
          },
          data: []
        }]
      }
    }
  },
  watch: {
    selected(newV) {
      this.initChart(newV)
    }
  },
  mounted() {
    this.$nextTick(() => {
      this.initChart(this.selected)
    })
  },
  methods: {
    initChart(data) {
      let seriesData = []
      switch (data) {
        case 'thermal':
          seriesData = [1228, 1206, 1257, 1302, 1273, 1333, 1377, 1423, 1452, 1457, 1501, 1489]
          break;
        case 'waterSupply':
          seriesData = [4483, 4437, 4631, 4798, 5011, 5134, 5379, 5942, 5969, 6109, 6213, 6245]
          break;
        case 'gas':
          seriesData = [3451, 3810, 4189, 4622, 4683, 4741, 4882, 5002, 5173, 5295, 5311, 5329]
          break;
        case 'integrated':
          seriesData = [13, 42, 120, 11, 42, 165, 70, 90, 22, 50, 57, 58]
          break;
        case 'waterlogging':
          seriesData = [4039, 4039, 4276, 4389, 4419, 4512, 4610, 4712, 4832, 4929, 5031, 5124]
          break;
        case 'fire':
          seriesData = [3460, 3877, 4189, 4572, 4683, 4711, 4782, 5038, 5163, 5238, 5304, 5390]
          break;
        case 'pipeRack':
          seriesData = [6772, 6959, 7082, 7235, 7248, 7386, 7505, 7583, 7905, 8024, 8157, 8157]
          break;
        default:
          break;
      }
      this.options.series[0].data = [...seriesData]
    }
  }
}
</script>

<style lang="scss" scoped>
.devOnlineLineContainer {
  //height: 100%;
  min-height: 100px;
  width: 100%;
  .chartBox {
    height: 100%;
  }
}
</style>
